@@ -1,6 +1,6 @@
 package Bundle::CPAN;
 
-$VERSION = '0.04';
+$VERSION = '1.40';
 
 1;
 
@@ -22,8 +22,6 @@ Compress::Zlib
 
 Archive::Tar
 
-Data::Dumper  # Bundle::libnet may have problems to work without it
-
 Bundle::libnet
 
 Term::ReadKey
@@ -49,10 +47,15 @@ Compress::Zlib needs as a prerequisite the zlib library. Currently
 (January 1998) this library is not shipped with the Compress::Zlib
 distribution.
 
+In this bundle Term::ReadLine::Perl is preferred over
+Term::ReadLine::Gnu because I
+have not come around to study the differences between the two.
+
 Note that all modules in this Bundle are not strict prerequisites to
-get a working CPAN.pm. CPAN.pm can work alone without any of the other
-modules just fine. The other modules are just goodies that make a
-smooth operation of CPAN.pm more likely.
+get a working CPAN.pm. CPAN.pm can work quite well without the other
+modules (except for Net::FTP which is really highly recommended). The
+other modules are just goodies that make a smooth operation of
+CPAN.pm more likely.
 
 =head1 AUTHOR
 
